# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"Database": "database.ipynb"}

modules = ["database.py"]

doc_url = "https://kandrio.github.io/minerva/"

git_url = "https://github.com/kandrio/minerva/tree/master/"

def custom_doc_links(name): return None
